/* "Sharing rule identification for general collective consumption models", by Laurens Cherchye, Bram De Rock, Arthur Lewbel and Frederic Vermeulen. */

/* This do-file constructs a dataset with consumption and labor suppy information drawn from the PSID. It starts from the datasets CoupleDataset1999.dta-CoupleDataset2009.dta. These datasets
contain the original data that can also be obtained from the website http://psidonline.isr.umich.edu/. It also makes use of the file CPIDef.dta, which contains price information that was gathered
via the website http://www.economagic.com, which is an economics time series page. */

* Last version: April 8, 2015

clear all
capture log close
set memory 500m
set maxvar 5000
set type double

log using "C:\ChooseLocation\sharingrule.log", replace

use "C:\ChooseLocation\CoupleDataset1999.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts1998 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts1998 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ WeeksWorkedHusband1998 HoursPerWeekWorkedHusband1998 /*HoursPerWeekOvertimeHusband1998*/ WagesSalaryHusband1998 /*ExtraJobsAmountHusband1998 LaborIncomeHusband1998 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife1998*/ HoursPerWeekWorkedWife1998 /*HoursPerWeekOvertimeWife1998*/ WagesSalaryWife1998 /*ExtraJobsAmountWife1998 LaborIncomeWife1998 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets1998 

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts1998
gen MedicalCosts=MedicalCosts1998
gen TotalAssets=TotalAssets1998
gen WeeksWorkedHusband=WeeksWorkedHusband1998
gen HoursPerWeekWorkedHusband=HoursPerWeekWorkedHusband1998
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband1998
gen WagesSalaryHusband=WagesSalaryHusband1998
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband1998
*gen LaborIncomeHusband=LaborIncomeHusband1998
gen HoursPerWeekWorkedWife=HoursPerWeekWorkedWife1998
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife1998
gen WagesSalaryWife=WagesSalaryWife1998

drop ChildCareCosts1998 MedicalCosts1998 TotalAssets1998 WeeksWorkedHusband1998 HoursPerWeekWorkedHusband1998 /*HoursPerWeekOvertimeHusband1998*/ WagesSalaryHusband1998 /*ExtraJobsAmountHusband1998 LaborIncomeHusband1998 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife1998*/ HoursPerWeekWorkedWife1998 /*HoursPerWeekOvertimeWife1998 WagesSalaryWife1998 ExtraJobsAmountWife1998 LaborIncomeWife1998  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets1998 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=44.6

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave1999.dta", replace
clear

***************

use "C:\ChooseLocation\CoupleDataset2001.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts2000 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts2000 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ WeeksWorkedHusband2000 HoursPerWeekWorkedHusband2000 /*HoursPerWeekOvertimeHusband2000*/ WagesSalaryHusband2000 /*ExtraJobsAmountHusband2000 LaborIncomeHusband2000 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2000*/ HoursPerWeekWorkedWife2000 /*HoursPerWeekOvertimeWife2000*/ WagesSalaryWife2000 /*ExtraJobsAmountWife2000 LaborIncomeWife2000 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets2000 

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts2000
gen MedicalCosts=MedicalCosts2000
gen TotalAssets=TotalAssets2000
gen WeeksWorkedHusband=WeeksWorkedHusband2000
gen HoursPerWeekWorkedHusband=HoursPerWeekWorkedHusband2000
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband2000
gen WagesSalaryHusband=WagesSalaryHusband2000
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband2000
*gen LaborIncomeHusband=LaborIncomeHusband2000
gen HoursPerWeekWorkedWife=HoursPerWeekWorkedWife2000
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife2000
gen WagesSalaryWife=WagesSalaryWife2000

drop ChildCareCosts2000 MedicalCosts2000 TotalAssets2000 WeeksWorkedHusband2000 HoursPerWeekWorkedHusband2000 /*HoursPerWeekOvertimeHusband2000*/ WagesSalaryHusband2000 /*ExtraJobsAmountHusband2000 LaborIncomeHusband2000 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2000*/ HoursPerWeekWorkedWife2000 /*HoursPerWeekOvertimeWife2000 WagesSalaryWife2000 ExtraJobsAmountWife2000 LaborIncomeWife2000  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets2000 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=44.6

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500
drop if Health==50000000
drop if Health>60000

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave2001.dta", replace
clear

***************

use "C:\ChooseLocation\CoupleDataset2003.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts2002 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts2002 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ WeeksWorkedHusband2002 HoursPerWeekWorkedHusband2002 /*HoursPerWeekOvertimeHusband2002*/ WagesSalaryHusband2002 /*ExtraJobsAmountHusband2002 LaborIncomeHusband2002 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2002*/ HoursPerWeekWorkedWife2002 /*HoursPerWeekOvertimeWife2002*/ WagesSalaryWife2002 /*ExtraJobsAmountWife2002 LaborIncomeWife2002 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets2002 

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts2002
gen MedicalCosts=MedicalCosts2002
gen TotalAssets=TotalAssets2002
gen WeeksWorkedHusband=WeeksWorkedHusband2002
gen HoursPerWeekWorkedHusband=HoursPerWeekWorkedHusband2002
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband2002
gen WagesSalaryHusband=WagesSalaryHusband2002
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband2002
*gen LaborIncomeHusband=LaborIncomeHusband2002
gen HoursPerWeekWorkedWife=HoursPerWeekWorkedWife2002
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife2002
gen WagesSalaryWife=WagesSalaryWife2002

drop ChildCareCosts2002 MedicalCosts2002 TotalAssets2002 WeeksWorkedHusband2002 HoursPerWeekWorkedHusband2002 /*HoursPerWeekOvertimeHusband2002*/ WagesSalaryHusband2002 /*ExtraJobsAmountHusband2002 LaborIncomeHusband2002 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2002*/ HoursPerWeekWorkedWife2002 /*HoursPerWeekOvertimeWife2002 WagesSalaryWife2002 ExtraJobsAmountWife2002 LaborIncomeWife2002  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets2002 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=44.6
* Missing. Average of 2001
replace WeeksWorkedHusband=49.08034

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500
drop if Health==50000000
drop if Health>60000

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave2003.dta", replace
clear

***************

use "C:\ChooseLocation\CoupleDataset2005.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts2004 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts2004 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ WeeksWorkedHusband2004 HoursPerWeekWorkedHusband2004 /*HoursPerWeekOvertimeHusband2004*/ WagesSalaryHusband2004 /*ExtraJobsAmountHusband2004 LaborIncomeHusband2004 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2004*/ HoursPerWeekWorkedWife2004 /*HoursPerWeekOvertimeWife2004*/ WagesSalaryWife2004 /*ExtraJobsAmountWife2004 LaborIncomeWife2004 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets2004 

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts2004
gen MedicalCosts=MedicalCosts2004
gen TotalAssets=TotalAssets2004
gen WeeksWorkedHusband=WeeksWorkedHusband2004
gen HoursPerWeekWorkedHusband=HoursPerWeekWorkedHusband2004
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband2004
gen WagesSalaryHusband=WagesSalaryHusband2004
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband2004
*gen LaborIncomeHusband=LaborIncomeHusband2004
gen HoursPerWeekWorkedWife=HoursPerWeekWorkedWife2004
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife2004
gen WagesSalaryWife=WagesSalaryWife2004

drop ChildCareCosts2004 MedicalCosts2004 TotalAssets2004 WeeksWorkedHusband2004 HoursPerWeekWorkedHusband2004 /*HoursPerWeekOvertimeHusband2004*/ WagesSalaryHusband2004 /*ExtraJobsAmountHusband2004 LaborIncomeHusband2004 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2004*/ HoursPerWeekWorkedWife2004 /*HoursPerWeekOvertimeWife2004 WagesSalaryWife2004 ExtraJobsAmountWife2004 LaborIncomeWife2004  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets2004 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=44.6
* Missing. Average of 2001
replace WeeksWorkedHusband=49.08034

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500
drop if Health==50000000
drop if Health>60000
drop if Education>100000

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave2005.dta", replace
clear

***************

use "C:\ChooseLocation\CoupleDataset2007.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts2006 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts2006 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ WeeksWorkedHusband2006 HoursPerWeekWorkedHusband2006 /*HoursPerWeekOvertimeHusband2006*/ WagesSalaryHusband2006 /*ExtraJobsAmountHusband2006 LaborIncomeHusband2006 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2006*/ HoursPerWeekWorkedWife2006 /*HoursPerWeekOvertimeWife2006*/ WagesSalaryWife2006 /*ExtraJobsAmountWife2006 LaborIncomeWife2006 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets2006 

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts2006
gen MedicalCosts=MedicalCosts2006
gen TotalAssets=TotalAssets2006
gen WeeksWorkedHusband=WeeksWorkedHusband2006
gen HoursPerWeekWorkedHusband=HoursPerWeekWorkedHusband2006
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband2006
gen WagesSalaryHusband=WagesSalaryHusband2006
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband2006
*gen LaborIncomeHusband=LaborIncomeHusband2006
gen HoursPerWeekWorkedWife=HoursPerWeekWorkedWife2006
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife2006
gen WagesSalaryWife=WagesSalaryWife2006

drop ChildCareCosts2006 MedicalCosts2006 TotalAssets2006 WeeksWorkedHusband2006 HoursPerWeekWorkedHusband2006 /*HoursPerWeekOvertimeHusband2006*/ WagesSalaryHusband2006 /*ExtraJobsAmountHusband2006 LaborIncomeHusband2006 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2006*/ HoursPerWeekWorkedWife2006 /*HoursPerWeekOvertimeWife2006 WagesSalaryWife2006 ExtraJobsAmountWife2006 LaborIncomeWife2006  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets2006 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=44.6
* Missing. Average of 2001
replace WeeksWorkedHusband=49.08034

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500
drop if Health==50000000
drop if Health>60000
drop if Education>100000

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave2007.dta", replace
clear

***************

use "C:\ChooseLocation\CoupleDataset2009.dta"

keep InterviewNr1999 PersonNumber Member PersonIndex SequenceNumber Year Sex MaritalStatus AgeHusband AgeWife EmploymentStatus ChildrenNumber GradeEducation Region/*
*/ ChildCareCosts2008 CarInsuranceVehicles RepairCostsVehicles GasolineCostsVehicles ParkingCostsVehicles SchoolExpenses RestaurantCosts /*
*/ HouseValue RentPaymentsMonthly HomeownerInsuranceAmount MedicalCosts2008 ElectricityMonthly HeatingMonthly WaterSewerMonthly OtherUtilitiesMonthly OtherTransportExpenses /*TelephoneMonthly*/ /*
*/ /*WeeksWorkedHusband2008 HoursPerWeekWorkedHusband2008 *//*HoursPerWeekOvertimeHusband2008*/ WagesSalaryHusband2008 /*ExtraJobsAmountHusband2008 LaborIncomeHusband2008 */ HourlyWageRateHusband ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2008 HoursPerWeekWorkedWife2008 */ /*HoursPerWeekOvertimeWife2008*/ WagesSalaryWife2008 /*ExtraJobsAmountWife2008 LaborIncomeWife2008 */ HourlyWageRateWife ExtraHourWageWife /*
*/ TotalAssets2008 TotalWeeklyWorkHoursHusb2008 TotalWeeklyWorkHoursWife2008 TotalWeeksWorkedHusband2008 TotalWeeksWorkedWife2008

gen ImputedRent=0.06*HouseValue /* Cf. imputation Blundell, Pistaferri, Saporta-Eksten (2012) */

gen ChildCareCosts=ChildCareCosts2008
gen MedicalCosts=MedicalCosts2008
gen TotalAssets=TotalAssets2008
*gen WeeksWorkedHusband=WeeksWorkedHusband2008
*gen HoursPerWeekOvertimeHusband=HoursPerWeekOvertimeHusband2008
gen WagesSalaryHusband=WagesSalaryHusband2008
*gen ExtraJobsAmountHusband=ExtraJobsAmountHusband2008
*gen LaborIncomeHusband=LaborIncomeHusband2008
gen HoursPerWeekWorkedHusband=TotalWeeklyWorkHoursHusb2008
gen HoursPerWeekWorkedWife=TotalWeeklyWorkHoursWife2008
*gen HoursPerWeekOvertimeWife=HoursPerWeekOvertimeWife2008
gen WagesSalaryWife=WagesSalaryWife2008

drop ChildCareCosts2008 MedicalCosts2008 TotalAssets2008 /*WeeksWorkedHusband2008 HoursPerWeekWorkedHusband2008*/ /*HoursPerWeekOvertimeHusband2008*/ WagesSalaryHusband2008 /*ExtraJobsAmountHusband2008 LaborIncomeHusband2008 HourlyWageRateHusband */ExtraHourWageHusband /*
*/ /*WeeksWorkedWife2008 HoursPerWeekWorkedWife2008 */ /*HoursPerWeekOvertimeWife2008 WagesSalaryWife2008 ExtraJobsAmountWife2008 LaborIncomeWife2008  HourlyWageRateWife ExtraHourWageWife */ /*
*/ TotalAssets2008 Member

*drop if GradeEducation==99
drop if ChildCareCosts==999999|ChildCareCosts==999998
drop if CarInsuranceVehicles==999999|CarInsuranceVehicles==999998
drop if RepairCostsVehicles==99999|RepairCostsVehicles==99998
drop if GasolineCostsVehicles==99999|GasolineCostsVehicles==99998
drop if ParkingCostsVehicles==99999|ParkingCostsVehicles==99998
drop if SchoolExpenses==999999|SchoolExpenses==999998
drop if RestaurantCosts==99999|RestaurantCosts==99998
drop if RentPaymentsMonthly==99999|RentPaymentsMonthly==99998
drop if HomeownerInsuranceAmount==9999|HomeownerInsuranceAmount==9998
drop if MedicalCosts==9999999|MedicalCosts==9999998
drop if ElectricityMonthly==9999|ElectricityMonthly==9998
drop if HeatingMonthly==9999|HeatingMonthly==9998
drop if WaterSewerMonthly==9999|WaterSewerMonthly==9998
drop if OtherTransportExpenses==99999|OtherTransportExpenses==99998
drop if HouseValue==9999999|HouseValue==9999998
*drop if WeeksWorkedHusband>52
drop if HoursPerWeekWorkedHusband>112
drop if HoursPerWeekWorkedWife>112
drop if WagesSalaryHusband==9999999|WagesSalaryHusband==9999998
drop if WagesSalaryWife==9999999|WagesSalaryWife==9999998
*drop if HoursPerWeekOvertimeHusband==9999|HoursPerWeekOvertimeHusband==9998
*drop if HoursPerWeekOvertimeWife==9999|HoursPerWeekOvertimeWife==9998

gen WeeksWorkedWife=TotalWeeksWorkedWife2008
gen WeeksWorkedHusband=TotalWeeksWorkedHusband2008 

drop if HoursPerWeekWorkedHusband==0
drop if HoursPerWeekWorkedWife==0
drop if WeeksWorkedHusband<40

gen WageRateHusband=WagesSalaryHusband/(HoursPerWeekWorkedHusband*WeeksWorkedHusband)
gen WageRateWife=WagesSalaryWife/(HoursPerWeekWorkedWife*WeeksWorkedWife)
replace WageRateHusband=HourlyWageRateHusband if WageRateHusband==0
replace WageRateWife=HourlyWageRateWife if WageRateWife==0

drop if WageRateHusband<3
drop if WageRateWife<3

gen HoursHusband=HoursPerWeekWorkedHusband*WeeksWorkedHusband
gen HoursWife=HoursPerWeekWorkedWife*WeeksWorkedWife

* See http://psidonline.isr.umich.edu/Data/SL/ConsumptionQsinPSID_1968-2009.xls for details on monthly/yearly/biennual expenses
gen FoodAtHome=99999
gen FoodOut=RestaurantCosts*12
gen Gasoline=GasolineCosts*12
gen Health=MedicalCosts/2
gen Utilities=(ElectricityMonthly+HeatingMonthly+WaterSewerMonthly+OtherUtilitiesMonthly)*12
gen Transportation=CarInsuranceVehicles+(RepairCostsVehicles+ParkingCostsVehicles+OtherTransportExpenses)*12
gen Education=SchoolExpenses
gen ChildCare=ChildCareCosts
gen HomeInsurance=HomeownerInsuranceAmount
gen Rent=RentPaymentsMonthly*12 if RentPaymentsMonthly>0
replace Rent=ImputedRent if HouseValue>0

drop if Rent==.|Rent<500
drop if Health==50000000
drop if Health>60000
drop if Education>100000

* Definition of household members
gen Member=.
* Male spouse
replace Member=1 if Sex==1
* Female spouse
replace Member=2 if Sex==2

* Allocation individual-specific variables not defined thus far.
gen GradeEducationHusband=GradeEducation if Member==1
gen GradeEducationWife=GradeEducation if Member==2

bysort InterviewNr1999: egen GradeEducationHusbandMean=mean(GradeEducationHusband)
bysort InterviewNr1999: egen GradeEducationWifeMean=mean(GradeEducationWife)

drop GradeEducationHusband GradeEducationWife
rename GradeEducationHusbandMean GradeEducationHusband
rename GradeEducationWifeMean GradeEducationWife

keep InterviewNr1999 Year Member AgeHusband AgeWife ChildrenNumber GradeEducationHusband GradeEducationWife Region /*
*/ HoursHusband HoursWife WageRateHusband WageRateWife /*
*/ FoodAtHome FoodOut Gasoline Health Utilities Transportation Education ChildCare HomeInsurance Rent

* We now construct household level file (with all individual information as well (reshaping is not needed given data construction. 
keep if Member==1
drop Member

save "C:\ChooseLocation\PSIDWave2009.dta", replace
clear

*** Merge sets ***
use "C:\ChooseLocation\PSIDWave1999.dta"
append using "C:\ChooseLocation\PSIDWave2001.dta"
append using "C:\ChooseLocation\PSIDWave2003.dta"
append using "C:\ChooseLocation\PSIDWave2005.dta"
append using "C:\ChooseLocation\PSIDWave2007.dta"
append using "C:\ChooseLocation\PSIDWave2009.dta"

sort InterviewNr1999 Year
save "C:\ChooseLocation\PSIDWave19992009.dta", replace
clear

**** Addition of prices and food ****
* At some point, food was not included. Happened later. So construct a data set with the name Data.dta with the missing food information (and the household identifier to merge the files).
use "C:\ChooseLocation\Data.dta", clear
keep InterviewNr1999 /*FoodSpent1999 FoodSpent2001 FoodSpent2003 FoodSpent2005 FoodSpent2007 FoodSpent2009  */ FoodUsedAtHome1999 FoodAtHome2001 FoodAtHome2003 FoodAtHome2005 FoodAtHome2007 FoodAtHome2009 

gen FoodAtHome1999=FoodUsedAtHome1999
drop FoodUsedAtHome1999

drop if FoodAtHome1999==99999|FoodAtHome1999==99998
drop if FoodAtHome2001==99999|FoodAtHome2001==99998
drop if FoodAtHome2003==99999|FoodAtHome2003==99998
drop if FoodAtHome2005==99999|FoodAtHome2005==99998
drop if FoodAtHome2007==99999|FoodAtHome2007==99998
drop if FoodAtHome2009==99999|FoodAtHome2009==99998

replace FoodAtHome1999=FoodAtHome1999*52
replace FoodAtHome2001=FoodAtHome2001*52
replace FoodAtHome2003=FoodAtHome2003*52
replace FoodAtHome2005=FoodAtHome2005*52
replace FoodAtHome2007=FoodAtHome2007*52
replace FoodAtHome2009=FoodAtHome2009*52

drop if FoodAtHome1999>30000
drop if FoodAtHome2001>30000
drop if FoodAtHome2003>30000
drop if FoodAtHome2005>30000
drop if FoodAtHome2007>30000
drop if FoodAtHome2009>30000

sort InterviewNr1999
duplicates drop InterviewNr1999, force

sort InterviewNr1999
save "C:\ChooseLocation\Food.dta", replace

use "C:\ChooseLocation\PSIDWave19992009.dta", clear
sort InterviewNr1999
merge InterviewNr1999 using "C:\ChooseLocation\Food.dta"
drop if Year==.
drop _merge

replace FoodAtHome=FoodAtHome1999 if Year==1999
replace FoodAtHome=FoodAtHome2001 if Year==2001
replace FoodAtHome=FoodAtHome2003 if Year==2003
replace FoodAtHome=FoodAtHome2005 if Year==2005
replace FoodAtHome=FoodAtHome2007 if Year==2007
replace FoodAtHome=FoodAtHome2009 if Year==2009

replace FoodAtHome=0 if FoodAtHome==.

drop FoodAtHome1999 FoodAtHome2001 FoodAtHome2003 FoodAtHome2005 FoodAtHome2007 FoodAtHome2009

drop if Region==0|Region==6

sort Year
save "C:\ChooseLocation\PSIDWave19992009.dta", replace

*bysort Year: sum

**** Merging prices from Economagic (wonderful website)
use "C:\ChooseLocation\CPIDef.dta", clear
sort Year
merge Year using "C:\ChooseLocation\PSIDWave19992009.dta"
drop _merge

gen PriceFoodAtHome=.
gen PriceFoodOut=.
gen PriceGasoline=.
gen PriceHealth=.
gen PriceUtilities=.
gen PriceTransportation=.
gen PriceEducation=.
gen PriceChildCare=.
gen PriceHomeInsurance=.
gen PriceRent=.

replace PriceFoodAtHome=PriceFoodAtHome1 if Region==1
replace PriceFoodOut=PriceFoodOut1 if Region==1
replace PriceGasoline=PriceGasoline1 if Region==1
replace PriceHealth=PriceHealth1 if Region==1
replace PriceUtilities=PriceUtilities1 if Region==1
replace PriceTransportation=PriceTransportation1 if Region==1
replace PriceEducation=PriceEducation1 if Region==1
replace PriceChildCare=PriceChildCare1 if Region==1
replace PriceHomeInsurance=PriceHomeInsurance1 if Region==1
replace PriceRent=PriceRent1 if Region==1

replace PriceFoodAtHome=PriceFoodAtHome2 if Region==2
replace PriceFoodOut=PriceFoodOut2 if Region==2
replace PriceGasoline=PriceGasoline2 if Region==2
replace PriceHealth=PriceHealth2 if Region==2
replace PriceUtilities=PriceUtilities2 if Region==2
replace PriceTransportation=PriceTransportation2 if Region==2
replace PriceEducation=PriceEducation2 if Region==2
replace PriceChildCare=PriceChildCare2 if Region==2
replace PriceHomeInsurance=PriceHomeInsurance2 if Region==2
replace PriceRent=PriceRent2 if Region==2

replace PriceFoodAtHome=PriceFoodAtHome3 if Region==3
replace PriceFoodOut=PriceFoodOut3 if Region==3
replace PriceGasoline=PriceGasoline3 if Region==3
replace PriceHealth=PriceHealth3 if Region==3
replace PriceUtilities=PriceUtilities3 if Region==3
replace PriceTransportation=PriceTransportation3 if Region==3
replace PriceEducation=PriceEducation3 if Region==3
replace PriceChildCare=PriceChildCare3 if Region==3
replace PriceHomeInsurance=PriceHomeInsurance3 if Region==3
replace PriceRent=PriceRent3 if Region==3

replace PriceFoodAtHome=PriceFoodAtHome4 if Region==4
replace PriceFoodOut=PriceFoodOut4 if Region==4
replace PriceGasoline=PriceGasoline4 if Region==4
replace PriceHealth=PriceHealth4 if Region==4
replace PriceUtilities=PriceUtilities4 if Region==4
replace PriceTransportation=PriceTransportation4 if Region==4
replace PriceEducation=PriceEducation4 if Region==4
replace PriceChildCare=PriceChildCare4 if Region==4
replace PriceHomeInsurance=PriceHomeInsurance4 if Region==4
replace PriceRent=PriceRent4 if Region==4

drop   PriceFoodAtHome1 PriceFoodAtHome2 PriceFoodAtHome3 PriceFoodAtHome4 PriceFoodOut1 PriceFoodOut2 PriceFoodOut3 PriceFoodOut4 PriceGasoline1 PriceGasoline2 PriceGasoline3 PriceGasoline4 /*
*/ PriceHealth1 PriceHealth2 PriceHealth3 PriceHealth4 PriceUtilities1 PriceUtilities2 PriceUtilities3 PriceUtilities4 PriceTransportation1 PriceTransportation2 PriceTransportation3 PriceTransportation4 /*
*/ PriceEducation1 PriceEducation2 PriceEducation3 PriceEducation4 PriceChildCare1 PriceChildCare2 PriceChildCare3 PriceChildCare4 PriceHomeInsurance1 PriceHomeInsurance2 PriceHomeInsurance3 PriceHomeInsurance4 /*
*/ PriceRent1 PriceRent2 PriceRent3 PriceRent4

*bysort Year: sum

gen Expenditure=FoodAtHome+FoodOut+Gasoline+Health+Utilities+Transportation+Education+ChildCare+HomeInsurance+Rent
sum Expenditure

gen Food=FoodAtHome+FoodOut
gen Housing=Utilities+HomeInsurance+Rent
gen Other=Gasoline+Health+Transportation+Education+ChildCare

egen BSFoodAtHome=mean(FoodAtHome/Food) 
egen BSFoodOut=mean(FoodOut/Food)

egen BSUtilities=mean(Utilities/Housing)
egen BSHomeInsurance=mean(HomeInsurance/Housing)
egen BSRent=mean(Rent/Housing)

egen BSGasoline=mean(Gasoline/Other)
egen BSHealth=mean(Health/Other)
egen BSTransportation=mean(Transportation/Other)
egen BSEducation=mean(Education/Other)
egen BSChildCare=mean(ChildCare/Other)

gen PriceFood=.
gen PriceHousing=.
gen PriceOther=.

replace PriceFood=PriceFoodAtHome^BSFoodAtHome*PriceFoodOut^BSFoodOut
replace PriceHousing=PriceUtilities^BSUtilities*PriceHomeInsurance^BSHomeInsurance*PriceRent^BSRent
replace PriceOther=PriceGasoline^BSGasoline*PriceHealth^BSHealth*PriceTransportation^BSTransportation*PriceEducation^BSEducation*PriceChildCare^BSChildCare

gen QuantFood=Food/PriceFood
gen QuantHousing=Housing/PriceHousing
gen QuantOther=Other/PriceOther

drop if QuantFood==.
drop if QuantHousing==.
drop if QuantOther==.

save "C:\ChooseLocation\PSIDWave19992009Complete.dta", replace

gen LeisureHusband=112*52-HoursHusband
gen LeisureWife=112*52-HoursWife
gen FullIncome=Expenditure+WageRateHusband*LeisureHusband+WageRateWife*LeisureWife

sort InterviewNr1999 Year

drop if Food==0
drop if Housing==0
drop if Other==0

gen Homeowner=1
replace Homeowner=0 if HomeInsurance==0

sum InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther Homeowner

egen FullIncome1nc=pctile(FullIncome) if ChildrenNumber==0, p(1) 
egen FullIncome99nc=pctile(FullIncome) if ChildrenNumber==0, p(99)

egen FullIncome1c=pctile(FullIncome) if ChildrenNumber>0, p(1) 
egen FullIncome99c=pctile(FullIncome) if ChildrenNumber>0, p(99)

drop if FullIncome<FullIncome1nc & ChildrenNumber==0
drop if FullIncome>FullIncome99nc & ChildrenNumber==0

drop if FullIncome<FullIncome1c & ChildrenNumber>0
drop if FullIncome>FullIncome99c & ChildrenNumber>0

sum InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther Homeowner if ChildrenNumber==0

sum InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther Homeowner if ChildrenNumber>0

sum InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther Homeowner

/* No children */
outsheet  InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther /*
*/ Homeowner /*
*/ using "C:\ChooseLocation\PSIDWave19992009NoChildren.txt" if ChildrenNumber==0, nonames replace comma

/* Children */
outsheet  InterviewNr1999 Year AgeHusband AgeWife ChildrenNumber Region GradeEducationHusband GradeEducationWife FullIncome /*
*/ LeisureHusband LeisureWife WageRateHusband WageRateWife QuantFood QuantHousing QuantOther PriceFood PriceHousing PriceOther /*
*/ Homeowner /*
*/ using "C:\ChooseLocation\PSIDWave19992009Children.txt" if ChildrenNumber>0, nonames replace comma



