
% Cherchye, De Rock, Lewbel and Vermeulen - Sharing rule identification.
% This programme reads data from PSID and computes sharing rule bounds. To estimate household demand, it applies a local linear regression
% method with constraints.

clear

run('C:\Program Files\tomlab\startup.m')

tic

load PSIDWave19992009NoChild.txt

global qe pe ye ass excl1 excl2 X nn numbass numbexcl Prob2 Prob3 Prob4 rows1_constraints rows2_constraints rows3_constraints rows4_constraints

InterviewNr1999=PSIDWave19992009NoChild(:,1);
Year=PSIDWave19992009NoChild(:,2);
AgeHusband=PSIDWave19992009NoChild(:,3); 
AgeWife=PSIDWave19992009NoChild(:,4); 
ChildrenNumber=PSIDWave19992009NoChild(:,5); 
Region=PSIDWave19992009NoChild(:,6); 
GradeEducationHusband=PSIDWave19992009NoChild(:,7); 
GradeEducationWife=PSIDWave19992009NoChild(:,8); 
FullIncome=PSIDWave19992009NoChild(:,9); 
LeisureHusband=PSIDWave19992009NoChild(:,10); 
LeisureWife=PSIDWave19992009NoChild(:,11); 
WageRateHusband=PSIDWave19992009NoChild(:,12); 
WageRateWife=PSIDWave19992009NoChild(:,13); 

QuantFood=PSIDWave19992009NoChild(:,14); 
QuantHousing=PSIDWave19992009NoChild(:,15); 
QuantOther=PSIDWave19992009NoChild(:,16); 

PriceFood=PSIDWave19992009NoChild(:,17); 
PriceHousing=PSIDWave19992009NoChild(:,18); 
PriceOther=PSIDWave19992009NoChild(:,19); 

X=[FullIncome LeisureHusband LeisureWife QuantFood QuantHousing QuantOther WageRateHusband WageRateWife PriceFood PriceHousing PriceOther];

[nobs nvar]=size(X);

nobs

nn=(nvar-1)/2; % number of goods

%compute mean budget shares
budgetsh=zeros(nobs,nn);
for j=1:nobs
    for i=1:nn
    budgetsh(j,i)=(X(j,1+i)*X(j,nn+1+i))/X(j,1);
    end
end
prices=X(:,nn+2:2*nn+1);
pricesmean=mean(prices);
quantities=X(:,2:nn+1);
quantitiesmean=mean(quantities);
income=X(:,1);
meanincome=mean(income);
budgetshmean=mean(budgetsh);

%% assignable (or private) and non-assignable (or non-private) goods (assignable=1; nonassignable=0)
ass=zeros(nn,1); %all goods private (1) or not (0)
ass(1)=1; %leisure male assignable
ass(2)=1; %leisure female assignable

numbass=ones(1,nn)*ass; %number of assignable goods

%exclusive goods for person 1 (excl1, husband) and 2 (excl2, wife)  (exclusive=1; nonexclusive=0)
excl1=zeros(nn,1); 
excl2=zeros(nn,1); 
excl1(1)=1; %leisure exclusive for male
excl2(2)=1; %leisure exclusive for female

numbexcl=ones(1,nn)*excl1+ones(1,nn)*excl2; %number of exclusive goods

%check whether exclusive only if assignable; error message if this is not the case
    for i=1:nn
        if excl1(i)==1
            if ass(i)==0
                error('Good can be exclusive to member 1 only if assignable (or private)!!');
            end
        end
        if excl2(i)==1
            if ass(i)==0
                error('Good can be exclusive to member 2 only if assignable (or private)!!');
            end
        end
    end

%define table of results (upper bound and lower bound for 9 deciles)
bestbounds1=zeros(nobs,2);
bestbounds2=zeros(nobs,2);
trivialbounds1=zeros(nobs,2);
trivialbounds2=zeros(nobs,2);

%% enumerating over obs
for obs=1:nobs %enumerating obs
obs

disp('***observation "obs" under evaluation***')


    
% Evaluation point

%observed point
pe=X(obs,nn+2:nn*2+1)' %prices
ye=X(obs,1)' %income
%qe=X(obs,2:nn+1)' %quantities

qe=QUAIDSSR1(pe,ye)

% Support
minprice=quantile(prices,0.00)'; %minwage
maxprice=quantile(prices,1.00)'; %maxwage
minexpend=quantile(income,0.00)'; %min income
maxexpend=quantile(income,1.00)'; %max income

%define grid for starting values income and for each 'grid step' k (number of steps = numstep) define
%bounds (1e column = upper bound 1; 2nd column = upper bound 2; 3rd column = objectivevalue (= sum of upper bounds))

numstep=5;

disp('***Total number of steps "numstep"***')
number_scenarios_k=numstep*numstep

bounds=zeros(numstep*numstep,3);
e=0.4/(numstep+1); %interval in grid

k=0;

for s=1:numstep
for t=1:numstep
    
disp('***Step number "k"***')
k=k+1

% initialize bounds for step k: trivial bounds
bounds(k,1)=(pe'*qe)-pe(2)*qe(2);
bounds(k,2)=(pe'*qe)-pe(1)*qe(1);
bounds(k,3)=bounds(k,1)+bounds(k,2);


% compute minprice over goods different from leisure (to define upper bound below)
absminpr=min(minprice(3:nn));

%define upper and lower bounds, and starting value for variables x0
lb=[minprice;minexpend;minprice;minexpend;zeros(4*nn,1);zeros(2,1)];   
ub=[maxprice;maxexpend;maxprice;maxexpend;(maxexpend/minprice(1));(maxexpend/minprice(2));(maxexpend/absminpr)*ones(nn-2,1);(maxexpend/minprice(1));(maxexpend/minprice(2));(maxexpend/absminpr)*ones(nn-2,1);(maxexpend/minprice(1));(maxexpend/minprice(2));(maxexpend/absminpr)*ones(nn-2,1);(maxexpend/minprice(1));(maxexpend/minprice(2));(maxexpend/absminpr)*ones(nn-2,1);maxexpend*ones(2,1)]; 


% Household demand in initial reference points

    %point 1 (starting prices; qr in other files)
    p1=ones(nn,1);
    p1(1,1)=pe(1,1)*1.5;
    p1(2,1)=pe(2,1)*0.66;
    p1(3:nn,1)=pe(3:nn,1);
    x1=ye*(0.8+s*e);
    q1=QUAIDSSR1(p1,x1)
      
    %point 2 (starting prices; qs in other files)
    p2=ones(nn,1);
    p2(1,1)=pe(1,1)*0.66;
    p2(2,1)=pe(2,1)*1.5;
    p2(3:nn,1)=pe(3:nn,1);
    x2=ye*(1.2-t*e);
    q2=QUAIDSSR1(p2,x2)


%number of variables is 6*nn+4, i.a.: nn prices p1 (var (1-nn)); income y1 (var (nn+1)); nn prices p2 (var (nn+2)-(2*nn+1)); income y2 (var (2*nn+2));
% 2*nn personalized quantities x1 (var (2*nn+3)-(4*nn+2)); 2*nn personalized quantities x2 (var (4*nn+2)-(6*nn+2)); 2 upper bounds on incomes (var (6*nn+3)-(6*nn+4))
%fill in starting values, including lower bounds prices and income
    
     x0=zeros(6*nn+4,1);
     x0(nn+1,:)=x1;
     x0(2*nn+2,:)=x2;
      for i=1:nn
         %1-nn and (nn+2)-(2*nn+1): starting prices for x1 and x2
            x0(i,:)=p1(i);
            x0(nn+1+i,:)=p2(i);
            
         %(2*nn+3)-(3*nn+2) and (3*nn+3)-(4*nn+2): starting values for personalized quantities for x1
          if excl1(i)==1;
            x0(2*nn+2+i,:)=q1(i);
          elseif  excl2(i)==1
            x0(3*nn+2+i,:)=q1(i);  
          else
           x0(2*nn+2+i,:)=0.5*q1(i);
           x0(3*nn+2+i,:)=0.5*q1(i);
          end
          
         %(4*nn+3)-(5*nn+2) and (5*nn+3)-(6*nn+2): starting values for personalized quantities for x2
          if excl1(i)==1
            x0(4*nn+2+i,:)=q2(i);
          elseif  excl2(i)==1
            x0(5*nn+2+i,:)=q2(i);  
          else
           x0(4*nn+2+i,:)=0.5*q2(i);
           x0(5*nn+2+i,:)=0.5*q2(i);
          end
      end
      
      %starting values upper income bounds member 1 and 2
      x0(6*nn+3)=x1;
      x0(6*nn+4)=x2;


%% four programs to define bounds  
     
options=optimset('Display','off');

%program 1
rows1_constraints_eq=2+2*numbass+2*numbexcl;
rows1_constraints_ineq=7+6*nn;
rows1_constraints=rows1_constraints_eq+rows1_constraints_ineq;
lbconst1=[zeros(rows1_constraints_eq,1);-inf*ones(rows1_constraints_ineq,1)];
Prob1=conAssign('PNPOPTPARAM_assObjSHrestr',[],[],[],lb,ub,[],x0,[],0,[],[],[],'PNPOPTPARAMconst_ass1SHrestr_tomrun',[],[],[],lbconst1,zeros(rows1_constraints,1));
Result1=tomRun('snopt',Prob1,0);
u1=Result1.x_k;
fval1=Result1.f_k;
exitflag1=Result1.Inform;

%program 2
rows2_constraints_eq=2+2*numbass+2*numbexcl;
rows2_constraints_ineq=8+6*nn;
rows2_constraints=rows2_constraints_eq+rows2_constraints_ineq;
lbconst2=[zeros(rows2_constraints_eq,1);-inf*ones(rows2_constraints_ineq,1)];
Prob2=conAssign('PNPOPTPARAM_assObjSHrestr',[],[],[],lb,ub,[],x0,[],0,[],[],[],'PNPOPTPARAMconst_ass2SHrestr_tomrun',[],[],[],lbconst2,zeros(rows2_constraints,1));
Result2=tomRun('snopt',Prob2,0);
u2=Result2.x_k;
fval2=Result2.f_k;
exitflag2=Result2.Inform;

%program 3
rows3_constraints_eq=2+2*numbass+2*numbexcl;
rows3_constraints_ineq=8+6*nn;
rows3_constraints=rows3_constraints_eq+rows3_constraints_ineq;
lbconst3=[zeros(rows3_constraints_eq,1);-inf*ones(rows3_constraints_ineq,1)];
Prob3=conAssign('PNPOPTPARAM_assObjSHrestr',[],[],[],lb,ub,[],x0,[],0,[],[],[],'PNPOPTPARAMconst_ass3SHrestr_tomrun',[],[],[],lbconst3,zeros(rows3_constraints,1));
Result3=tomRun('snopt',Prob3,0);
u3=Result3.x_k;
fval3=Result3.f_k;
exitflag3=Result3.Inform;

%program 4
rows4_constraints_eq=2+2*numbass+2*numbexcl;
rows4_constraints_ineq=7+6*nn;
rows4_constraints=rows4_constraints_eq+rows4_constraints_ineq;
lbconst4=[zeros(rows4_constraints_eq,1);-inf*ones(rows4_constraints_ineq,1)];
Prob4=conAssign('PNPOPTPARAM_assObjSHrestr',[],[],[],lb,ub,[],x0,[],0,[],[],[],'PNPOPTPARAMconst_ass4SHrestr_tomrun',[],[],[],lbconst4,zeros(rows4_constraints,1));
Result4=tomRun('snopt',Prob4,0);
u4=Result4.x_k;
fval4=Result4.f_k;
exitflag4=Result4.Inform;


% record upper bounds for shares and exitflags in 4 scenarios
yu1=zeros(4,1);
yu2=zeros(4,1);
exit=zeros(4,1);
obj_value=zeros(4,1);
yu1(1)=u1(6*nn+3); yu2(1)=u1(6*nn+4); yu1(2)=u2(6*nn+3); yu2(2)=u2(6*nn+4); yu1(3)=u3(6*nn+3); yu2(3)=u3(6*nn+4); yu1(4)=u4(6*nn+3); yu2(4)=u4(6*nn+4);
exit(1)=exitflag1; exit(2)=exitflag2; exit(3)=exitflag3; exit(4)=exitflag4;
obj_value(1)=fval1; obj_value(2)=fval2; obj_value(3)=fval3; obj_value(4)=fval4;

%summary: using exitflags to define new vectors exitnew, yu1new, yu2new and
%obj_value
exitnew=100*ones(4,1);
yu1new=zeros(4,1);
yu2new=zeros(4,1);
obj_valuenew=ones(4,1)*max(obj_value)+100;
for i=1:4
    if abs(exit(i))== 1
        if obj_value(i)>0.000001
            if yu1(i)>pe(1)*qe(1) %acceptable upper bound 1 (i.e. above trivial lower bound)         
                if yu2(i)>pe(2)*qe(2) %acceptable upper bound 2 (i.e. above trivial lower bound)
                    exitnew(i)=abs(exit(i));
                    yu1new(i)=yu1(i);
                    yu2new(i)=yu2(i);
                    obj_valuenew(i)=obj_value(i);
                end
            end
        end
    elseif abs(exit(i))== 2
        if obj_value(i)>0.000001
            if yu1(i)>pe(1)*qe(1) %acceptable upper bound 1 (i.e. above trivial lower bound)         
                if yu2(i)>pe(2)*qe(2) %acceptable upper bound 2 (i.e. above trivial lower bound)
                    exitnew(i)=abs(exit(i));
                    yu1new(i)=yu1(i);
                    yu2new(i)=yu2(i);
                    obj_valuenew(i)=obj_value(i);
                end
            end
        end
    elseif abs(exit(i))== 3
        if obj_value(i)>0.000001
            if yu1(i)>pe(1)*qe(1) %acceptable upper bound 1 (i.e. above trivial lower bound)         
                if yu2(i)>pe(2)*qe(2) %acceptable upper bound 2 (i.e. above trivial lower bound)
                    exitnew(i)=abs(exit(i));
                    yu1new(i)=yu1(i);
                    yu2new(i)=yu2(i);
                    obj_valuenew(i)=obj_value(i);
                end
            end
        end
    end
end

if min(exitnew)==1
    for i=1:4
    	if obj_valuenew(i)==min(obj_valuenew)
                bounds(k,1)=yu1new(i);
                bounds(k,2)=yu2new(i);
                bounds(k,3)=obj_valuenew(i);
        end
    end
elseif min(exitnew)== 2
    for i=1:4
    	if obj_valuenew(i)==min(obj_valuenew)
                bounds(k,1)=yu1new(i);
                bounds(k,2)=yu2new(i);
                bounds(k,3)=obj_valuenew(i);
        end
    end
elseif min(exitnew)== 3
    for i=1:4
    	if obj_valuenew(i)==min(obj_valuenew)
                bounds(k,1)=yu1new(i);
                bounds(k,2)=yu2new(i);
                bounds(k,3)=obj_valuenew(i);
        end
    end
end

disp('***"bounds" for given step number "k": (1) upper bound 1; (2) upper bound 2; (3) objective value (= sum of upper bounds)***')
bounds(k,:)

end %end grid starting values i
end %end grid starting values j

disp('***summary "bounds" for all steps: (1) upper bound 1; (2) upper bound 2; (3) objective value (= sum of upper bounds)***')
bounds

%% display results 
disp('***RESULTS: SUMMARY REPORT***')

disp('observation:')
obs

for k=1:numstep*numstep   
   if bounds(k,3)==min(bounds(:,3))
      upper1=min((pe'*qe)-pe(2)*qe(2), bounds(k,1)); %min of trivial and computed bounds for 1
      upper2=min((pe'*qe)-pe(1)*qe(1), bounds(k,2)); %min of trivial and computed bounds for 2
      bounds1=[(pe'*qe)-upper2 upper1];
      bounds2=[(pe'*qe)-upper1 upper2];
   end
end

bounds1
bounds2

disp('***Compare: trivial bounds***')
        trivial1=[pe(1)*qe(1) (pe'*qe)-pe(2)*qe(2)]
        trivial2=[pe(2)*qe(2) (pe'*qe)-pe(1)*qe(1)]

%register results
bestbounds1(obs,:)=bounds1;
bestbounds2(obs,:)=bounds2;
trivialbounds1(obs,:)=trivial1;
trivialbounds2(obs,:)=trivial2;

%% save results
% bestbounds1
resultpath='results';
filename_bestbounds1=['Results_perhh_bestbounds1.txt'];
fullfilename_bestbounds1=fullfile(resultpath,filename_bestbounds1);
dlmwrite(fullfilename_bestbounds1, bestbounds1, 'delimiter', '\t', 'newline', 'pc');

% bestbounds2
filename_bestbounds2=['Results_perhh_bestbounds2.txt'];
fullfilename_bestbounds2=fullfile(resultpath,filename_bestbounds2);
dlmwrite(fullfilename_bestbounds2, bestbounds2, 'delimiter', '\t', 'newline', 'pc');

% trivialbounds1
filename_trivialbounds1=['Results_perhh_trivialbounds1.txt'];
fullfilename_trivialbounds1=fullfile(resultpath,filename_trivialbounds1);
dlmwrite(fullfilename_trivialbounds1, trivialbounds1, 'delimiter', '\t', 'newline', 'pc');

% trivialbounds2
filename_trivialbounds2=['Results_perhh_trivialbounds2.txt'];
fullfilename_trivialbounds2=fullfile(resultpath,filename_trivialbounds2);
dlmwrite(fullfilename_trivialbounds2, trivialbounds2, 'delimiter', '\t', 'newline', 'pc');

end %end grid for observations

bestbounds1
bestbounds2
trivialbounds1
trivialbounds2

toc
totalruntime=toc/60